@@ -24,6 +24,6 @@ else:
 
 
 class MemcachedConfig:
-    HOST = os.environ.get("MEMCACHED_HOST", "127.0.0.1")
+    HOST = os.environ.get("MEMCACHE_HOST", "127.0.0.1")
     PORT = "11211"
 
